from logger import Logger
from services.basicservice import BasicService
from servicestub import ServiceStub
from singleton import Singleton
from typing import Dict, Any
import bottle
import json
import os
import xml.etree.ElementTree as ET


class Loymax(BasicService, metaclass=Singleton):
    log: Logger
    cases: Dict[str, Dict[str, Any]]

    def __init__(self):
        super().__init__()
        self.servicePath = os.path.dirname(os.path.abspath(__file__))

    def registerRoutes(self, servicestub: ServiceStub):
        self.log.info('Регистрация сервиса Loymax')
        self.__updateCases()

        servicestub.route('/loymax', method='POST', callback=self.handler)

    def handler(self):
        root = ET.fromstring(bottle.request.body.read())
        action = "undefined"

        if root.find(".//Balances"):
            action = "Balances"
        elif root.find(".//Calculates"):
            action = "Calculates"
        elif root.find(".//Discounts"):
            action = "Discounts"
        elif root.find(".//ConfirmPurchases"):
            action = "ConfirmPurchases"
        elif root.find(".//CancelPurchases"):
            action = "CancelPurchases"
        elif root.find(".//Payments"):
            action = "Payments"
        elif root.find(".//Refunds"):
            action = "Refunds"
        elif root.find(".//AvailableAmounts"):
            action = "AvailableAmounts"
        elif root.find(".//CancelOperations"):
            action = "CancelOperations"


        self.log.info("Действие: %s", action)
        return self._createXmlResponse("%s" % action)

    def __updateCases(self):
        try:
            with open(os.path.join(self.servicePath, 'cases.json'), 'r') as cases:
                self.cases = json.load(cases)
        except Exception as e:
            self.log.error(str(e))

instance = Loymax()
